@@ -193,7 +193,7 @@ class CreateAsyncRecognitionTaskRequest(AbstractModel):
 • 16k_en：16k 英语；
 • 16k_ca：16k 粤语；
         :type EngineType: str
-        :param Url: 语音流地址，支持rtmp、hls、rtsp等流媒体协议，以及各类基于http协议的直播流
+        :param Url: 语音流地址，支持rtmp、rtsp等流媒体协议，以及各类基于http协议的直播流(不支持hls, m3u8)
         :type Url: str
         :param CallbackUrl: 支持HTTP和HTTPS协议，用于接收识别结果，您需要自行搭建公网可调用的服务。回调格式&内容详见：[语音流异步识别回调说明](https://cloud.tencent.com/document/product/1093/52633)
         :type CallbackUrl: str
@@ -335,7 +335,7 @@ class CreateRecTaskRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param EngineModelType: 引擎模型类型。
+        :param EngineModelType: 引擎模型类型。注意：非电话场景请务必使用16k的引擎。
 电话场景：
 • 8k_en：电话 8k 英语；
 • 8k_zh：电话 8k 中文普通话通用；
@@ -349,11 +349,12 @@ class CreateRecTaskRequest(AbstractModel):
 • 16k_en_edu 英文教育；
 • 16k_zh_medical  医疗；
 • 16k_th 泰语；
-• 16k_zh_dialect：多方言，支持23种方言。
+• 16k_zh-PY 中英粤;
+• 16k_zh_dialect：多方言，支持23种方言（上海话、四川话、武汉话、贵阳话、昆明话、西安话、郑州话、太原话、兰州话、银川话、西宁话、南京话、合肥话、南昌话、长沙话、苏州话、杭州话、济南话、天津话、石家庄话、黑龙江话、吉林话、辽宁话）；
         :type EngineModelType: str
         :param ChannelNum: 识别声道数。1：单声道（非电话场景，直接选择单声道即可，忽略音频声道数）；2：双声道（仅支持8k_zh电话场景，双声道应分别对应通话双方）。注意：双声道的电话音频已物理分离说话人，无需再开启说话人分离功能。
         :type ChannelNum: int
-        :param ResTextFormat: 识别结果返回形式。0： 识别结果文本(含分段时间戳)； 1：词级别粒度的[详细识别结果](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)(不含标点，含语速值)；2：词级别粒度的详细识别结果（包含标点、语速值）
+        :param ResTextFormat: 识别结果返回形式。0： 识别结果文本(含分段时间戳)； 1：词级别粒度的[详细识别结果](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)(不含标点，含语速值)；2：词级别粒度的详细识别结果（包含标点、语速值）；3: 标点符号分段，包含每段时间戳，特别适用于字幕场景（包含词级时间、标点、语速值）。
         :type ResTextFormat: int
         :param SourceType: 语音数据来源。0：语音 URL；1：语音数据（post body）。
         :type SourceType: int
@@ -365,7 +366,7 @@ class CreateRecTaskRequest(AbstractModel):
         :type SpeakerNumber: int
         :param CallbackUrl: 回调 URL，用户自行搭建的用于接收识别结果的服务URL。如果用户使用轮询方式获取识别结果，则无需提交该参数。回调格式&内容详见：[录音识别回调说明](https://cloud.tencent.com/document/product/1093/52632)
         :type CallbackUrl: str
-        :param Url: 语音的URL地址，需要公网可下载。长度小于2048字节，当 SourceType 值为 0 时须填写该字段，为 1 时不需要填写。注意：请确保录音文件时长在5个小时之内，否则可能识别失败。请保证文件的下载速度，否则可能下载失败。
+        :param Url: 语音的URL地址，需要公网环境浏览器可下载。当 SourceType 值为 0 时须填写该字段，为 1 时不需要填写。注意：请确保录音文件时长在5个小时之内，否则可能识别失败。请保证文件的下载速度，否则可能下载失败。
         :type Url: str
         :param Data: 语音数据base64编码，当SourceType 值为1时必须填写，为0可不写。音频数据要小于5MB。
         :type Data: str
@@ -375,9 +376,9 @@ class CreateRecTaskRequest(AbstractModel):
         :type ConvertNumMode: int
         :param FilterDirty: 是否过滤脏词（目前支持中文普通话引擎）。0：不过滤脏词；1：过滤脏词；2：将脏词替换为 * 。默认值为 0。
         :type FilterDirty: int
-        :param HotwordId: 热词表id。如不设置该参数，自动生效默认热词表；如果设置了该参数，那么将生效对应的热词表。
+        :param HotwordId: 热词表id。如不设置该参数，自动生效默认热词表；如设置了该参数，那么将生效对应的热词表。
         :type HotwordId: str
-        :param CustomizationId: 自学习模型 id。如不设置该参数，自动生效最后一次上线的自学习模型；如果设置了该参数，那么将生效对应的自学习模型。
+        :param CustomizationId: 自学习模型 id。如设置了该参数，将生效对应的自学习模型。
         :type CustomizationId: str
         :param Extra: 附加参数(该参数无意义，忽略即可)
         :type Extra: str
@@ -385,6 +386,15 @@ class CreateRecTaskRequest(AbstractModel):
         :type FilterPunc: int
         :param FilterModal: 是否过滤语气词（目前支持中文普通话引擎）。0：不过滤语气词；1：部分过滤；2：严格过滤 。默认值为 0。
         :type FilterModal: int
+        :param EmotionalEnergy: 情绪能量值，取值为音量分贝值/10。取值范围：[1,10]。值越高情绪越强烈。0:不开启，1:开启
+        :type EmotionalEnergy: int
+        :param ReinforceHotword: 热词增强功能。1:开启后（仅支持8k_zh,16k_zh），将开启同音替换功能，同音字、词在热词中配置。举例：热词配置“蜜制”并开启增强功能后，与“蜜制”同拼音（mizhi）的“秘制”的识别结果会被强制替换成“蜜制”。因此建议客户根据自己的实际情况开启该功能。
+        :type ReinforceHotword: int
+        :param SentenceMaxLength: 单标点最多字数，取值范围：[6，40]。默认为0，不开启该功能。该参数可用于字幕生成场景，控制单行字幕最大字数（设置ResTextFormat为3，解析返回的ResultDetail列表，通过结构中FinalSentence获取单个标点断句结果）。
+        :type SentenceMaxLength: int
+        :param EmotionRecognition: 情绪识别能力(目前支持16k_zh) 默认为0，不开启。 1：开启情绪识别但是不会在文本展示“情绪标签”， 2：开启情绪识别并且在文本展示“情绪标签”。（该功能需要设置ResTextFormat 大于0）
+注意：本功能为增值服务，购买对应套餐包后，将参数设置为1或2时方可按对应方式生效，并消耗套餐包对应资源。参数设置为0时无需购买套餐包，也不会消耗对应资源。
+        :type EmotionRecognition: int
         """
         self.EngineModelType = None
         self.ChannelNum = None
@@ -403,6 +413,10 @@ class CreateRecTaskRequest(AbstractModel):
         self.Extra = None
         self.FilterPunc = None
         self.FilterModal = None
+        self.EmotionalEnergy = None
+        self.ReinforceHotword = None
+        self.SentenceMaxLength = None
+        self.EmotionRecognition = None
 
 
     def _deserialize(self, params):
@@ -423,6 +437,10 @@ class CreateRecTaskRequest(AbstractModel):
         self.Extra = params.get("Extra")
         self.FilterPunc = params.get("FilterPunc")
         self.FilterModal = params.get("FilterModal")
+        self.EmotionalEnergy = params.get("EmotionalEnergy")
+        self.ReinforceHotword = params.get("ReinforceHotword")
+        self.SentenceMaxLength = params.get("SentenceMaxLength")
+        self.EmotionRecognition = params.get("EmotionRecognition")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1122,6 +1140,15 @@ class SentenceDetail(AbstractModel):
         :param SpeakerId: 声道或说话人 Id（请求中如果设置了 speaker_diarization或者ChannelNum为双声道，可区分说话人或声道）
 注意：此字段可能返回 null，表示取不到有效值。
         :type SpeakerId: int
+        :param EmotionalEnergy: 情绪能量值，取值为音量分贝值/10。取值范围：[1,10]。值越高情绪越强烈。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type EmotionalEnergy: float
+        :param SilenceTime: 本句与上一句之间的静音时长
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SilenceTime: int
+        :param EmotionType: 情绪类型（可能为空）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type EmotionType: list of str
         """
         self.FinalSentence = None
         self.SliceSentence = None
@@ -1131,6 +1158,9 @@ class SentenceDetail(AbstractModel):
         self.Words = None
         self.SpeechSpeed = None
         self.SpeakerId = None
+        self.EmotionalEnergy = None
+        self.SilenceTime = None
+        self.EmotionType = None
 
 
     def _deserialize(self, params):
@@ -1147,6 +1177,9 @@ class SentenceDetail(AbstractModel):
                 self.Words.append(obj)
         self.SpeechSpeed = params.get("SpeechSpeed")
         self.SpeakerId = params.get("SpeakerId")
+        self.EmotionalEnergy = params.get("EmotionalEnergy")
+        self.SilenceTime = params.get("SilenceTime")
+        self.EmotionType = params.get("EmotionType")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1163,7 +1196,7 @@ class SentenceRecognitionRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param ProjectId: 腾讯云项目 ID，可填 0，总长度不超过 1024 字节。
+        :param ProjectId: 腾讯云项目 ID，废弃参数，填写0即可。
         :type ProjectId: int
         :param SubServiceType: 子服务类型。2： 一句话识别。
         :type SubServiceType: int
@@ -1177,22 +1210,23 @@ class SentenceRecognitionRequest(AbstractModel):
 • 16k_ca：16k 粤语；
 • 16k_ja：16k 日语；
 • 16k_zh_medical：16k 医疗；
-• 16k_zh_dialect：多方言，支持23种方言。
+• 16k_zh-PY 中英粤;
+• 16k_zh_dialect：多方言，支持23种方言（上海话、四川话、武汉话、贵阳话、昆明话、西安话、郑州话、太原话、兰州话、银川话、西宁话、南京话、合肥话、南昌话、长沙话、苏州话、杭州话、济南话、天津话、石家庄话、黑龙江话、吉林话、辽宁话）；
         :type EngSerViceType: str
         :param SourceType: 语音数据来源。0：语音 URL；1：语音数据（post body）。
         :type SourceType: int
         :param VoiceFormat: 识别音频的音频格式，支持wav、pcm、ogg-opus、speex、silk、mp3、m4a、aac。
         :type VoiceFormat: str
-        :param UsrAudioKey: 用户端对此任务的唯一标识，用户自助生成，用于用户查找识别结果。
+        :param UsrAudioKey: 废弃参数，填写任意字符串即可。
         :type UsrAudioKey: str
-        :param Url: 语音 URL，公网可下载。当 SourceType 值为 0（语音 URL上传） 时须填写该字段，为 1 时不填；URL 的长度大于 0，小于 2048，需进行urlencode编码。音频时长不能超过60s，音频文件大小不能超过3MB。
+        :param Url: 语音的URL地址，需要公网环境浏览器可下载。当 SourceType 值为 0时须填写该字段，为 1 时不填。音频时长不能超过60s，音频文件大小不能超过3MB。
         :type Url: str
         :param Data: 语音数据，当SourceType 值为1（本地语音数据上传）时必须填写，当SourceType 值为0（语音 URL上传）可不写。要使用base64编码(采用python语言时注意读取文件应该为string而不是byte，以byte格式读取后要decode()。编码后的数据不可带有回车换行符)。音频时长不能超过60s，音频文件大小不能超过3MB（Base64后）。
         :type Data: str
         :param DataLen: 数据长度，单位为字节。当 SourceType 值为1（本地语音数据上传）时必须填写，当 SourceType 值为0（语音 URL上传）可不写（此数据长度为数据未进行base64编码时的数据长度）。
         :type DataLen: int
-        :param HotwordId: 热词id。用于调用对应的热词表，如果在调用语音识别服务时，不进行单独的热词id设置，自动生效默认热词；如果进行了单独的热词id设置，那么将生效单独设置的热词id。
-        :type HotwordId: str
+        :param WordInfo: 是否显示词级别时间戳。0：不显示；1：显示，不包含标点时间戳，2：显示，包含标点时间戳。默认值为 0。
+        :type WordInfo: int
         :param FilterDirty: 是否过滤脏词（目前支持中文普通话引擎）。0：不过滤脏词；1：过滤脏词；2：将脏词替换为 * 。默认值为 0。
         :type FilterDirty: int
         :param FilterModal: 是否过语气词（目前支持中文普通话引擎）。0：不过滤语气词；1：部分过滤；2：严格过滤 。默认值为 0。
@@ -1201,8 +1235,12 @@ class SentenceRecognitionRequest(AbstractModel):
         :type FilterPunc: int
         :param ConvertNumMode: 是否进行阿拉伯数字智能转换。0：不转换，直接输出中文数字，1：根据场景智能转换为阿拉伯数字。默认值为1。
         :type ConvertNumMode: int
-        :param WordInfo: 是否显示词级别时间戳。0：不显示；1：显示，不包含标点时间戳，2：显示，包含标点时间戳。默认值为 0。
-        :type WordInfo: int
+        :param HotwordId: 热词id。用于调用对应的热词表，如果在调用语音识别服务时，不进行单独的热词id设置，自动生效默认热词；如果进行了单独的热词id设置，那么将生效单独设置的热词id。
+        :type HotwordId: str
+        :param CustomizationId: 自学习模型 id。如设置了该参数，将生效对应的自学习模型。
+        :type CustomizationId: str
+        :param ReinforceHotword: 热词增强功能。1:开启后（仅支持8k_zh,16k_zh），将开启同音替换功能，同音字、词在热词中配置。举例：热词配置“蜜制”并开启增强功能后，与“蜜制”同拼音（mizhi）的“秘制”、“蜜汁”的识别结果会被强制替换成“蜜制”。因此建议客户根据自己的实际情况开启该功能。
+        :type ReinforceHotword: int
         """
         self.ProjectId = None
         self.SubServiceType = None
@@ -1213,12 +1251,14 @@ class SentenceRecognitionRequest(AbstractModel):
         self.Url = None
         self.Data = None
         self.DataLen = None
-        self.HotwordId = None
+        self.WordInfo = None
         self.FilterDirty = None
         self.FilterModal = None
         self.FilterPunc = None
         self.ConvertNumMode = None
-        self.WordInfo = None
+        self.HotwordId = None
+        self.CustomizationId = None
+        self.ReinforceHotword = None
 
 
     def _deserialize(self, params):
@@ -1231,12 +1271,14 @@ class SentenceRecognitionRequest(AbstractModel):
         self.Url = params.get("Url")
         self.Data = params.get("Data")
         self.DataLen = params.get("DataLen")
-        self.HotwordId = params.get("HotwordId")
+        self.WordInfo = params.get("WordInfo")
         self.FilterDirty = params.get("FilterDirty")
         self.FilterModal = params.get("FilterModal")
         self.FilterPunc = params.get("FilterPunc")
         self.ConvertNumMode = params.get("ConvertNumMode")
-        self.WordInfo = params.get("WordInfo")
+        self.HotwordId = params.get("HotwordId")
+        self.CustomizationId = params.get("CustomizationId")
+        self.ReinforceHotword = params.get("ReinforceHotword")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
